/*
 * Sven Kratz, Michael Rohs (c) 2011
 */
package de.lmu.mobilehci.gesturewizards;

import android.content.Context;
import android.view.View;

/**
 * This is the model in the MVC pattern. The corresponding view is created on demand (getView).
 *
 */
public class Spell {

	// the set of spells the wizards know
	public enum SpellType { Earth, Air, Fire, EarthDefense, AirDefense, FireDefense }; 

	// detail information on the spell
	public SpellInfo spellInfo;

	private Context context;
	
	// in the MVC pattern: Spell = model, SpellView = view
	private SpellView spellView = null;
	
	// the wizard who has cast the spell
	public Wizard wizard;

	// the animation to play (refers to an XML file)
	public int animationResource;
	
	public Spell(Context c, SpellInfo si, Wizard w, int a) {
		context = c;
		spellInfo = si;
		wizard = w;
		animationResource = a;
	}
	
	public void cancelAnimation() {
		spellView.setVisibility(View.INVISIBLE);
		spellView.clearAnimation();
	}
	
	public SpellView getView() {
		if (spellView == null) {
			spellView = new SpellView(context, this);
		}
		return spellView;
	}
	
	public boolean isDefenseSpell() {
		return spellInfo.defensive;
	}

	// checks whether s is the counterpart of this spell, e.g., "air" matches "defair"
	public boolean matches(Spell s) {
		return spellInfo.matchingSpellType == s.spellInfo.spellType;
	}
}
